@@ -9,7 +9,7 @@ use io_uring::cqueue::buffer_select;
 use io_uring::squeue::Flags;
 use io_uring::{opcode, types};
 
-use crate::driver::buffers::ProvidedBuf;
+use crate::driver::buffers::{ProvidedBuf, GROUP_ID};
 use crate::driver::Action;
 
 pub struct Read;
@@ -17,7 +17,7 @@ pub struct Read;
 impl Action<Read> {
     pub fn read(fd: RawFd, len: u32) -> io::Result<Action<Read>> {
         let entry = opcode::Read::new(types::Fd(fd), ptr::null_mut(), len)
-            .buf_group(0)
+            .buf_group(GROUP_ID)
             .build()
             .flags(Flags::BUFFER_SELECT);
         Action::submit(Read, entry)
