@@ -103,7 +103,7 @@ impl Inner {
                     self.read = Read::Idle;
                     self.read_pos = 0;
                     if self.rd.is_empty() {
-                        return Poll::Ready(Err(io::ErrorKind::UnexpectedEof.into()));
+                        return Poll::Ready(Ok(&self.rd[..]));
                     }
                 }
             }
